Function called internally by drtmle to perform the fluctuation of the initial estimator of g (i.e., solves the new estimating eqn that results from misspecification of Q)
fluctuateG(Y, A, W, DeltaY, DeltaA, a_0, gn, Qrn, tolg, coefTol = 1000)The outcome
The treatment
The covariates
Indicator of missing outcome (assumed to be equal to 0 if missing 1 if observed)
Indicator of missing treatment (assumed to be equal to 0 if missing 1 if observed)
A list of fixed treatment values
A list of propensity regression estimates evaluated on observed data
A list of reduced-dimension regression estimates evaluated on observed data
The lower bound on propensity score estimates
A tolerance level on the magnitude of the coefficient that flags the result as potentially the result of numeric instability.