Function called internally by drtmle to perform the first fluctuation of the initial estimator of Q (i.e., solves the original EIF estimating eqn)
fluctuateQ1(Y, A, W, DeltaA, DeltaY, Qn, gn, a_0, coefTol = 1000)The outcome
The treatment
The covariates
Indicator of missing treatment (assumed to be equal to 0 if missing 1 if observed)
Indicator of missing outcome (assumed to be equal to 0 if missing 1 if observed)
A list of outcome regression estimates evaluated on observed data
A list of propensity regression estimates evaluated on observed data
A list of fixed treatment values
A tolerance level on the magnitude of the coefficient that flags the result as potentially the result of numeric instability.